pub trait RigidBodyForces: ReadRigidBodyForces + WriteRigidBodyForces { }Expand description
A trait for reading and writing forces of a dynamic rigid body.
This is implemented as a shared interface for the ForcesItem and NonWakingForcesItem
returned by Forces.
See the documentation of Forces for more information on how to work with forces in Avian.